@@ -13,8 +13,20 @@
 
 
 Plotters is a flexible drawing library for data visualization written in pure Rust.
-The library isn't aimed supporting different types of plotting, but a generic platform
-that can be extended to support different types of visualization methods.
+
+- Why plotting in Rust?
+Although rendering a figure doesn't requires too many computation power in most of the case, 
+and programming language such as Python and Javascript is used for visualization purpose.
+Sometimes we need to make a figure based on huge amount of data, for example, rendering some
+human gene data may requires to downsampling trillions data points, which isn't even doable
+with many high-level programming language. In this case, Rust is a perfect candidate for rendering 
+figures, since it runs very fast while having high-level abstraction abilities. 
+
+- What type of figure is supported?
+Currently, we support line series, point series and candlestick series. 
+And the library is designed to be able to render multiple figure into a single image. 
+But Plotter is aimed to be a platform that is fully extendable to supporting any other types of figure.
+
 
 ## Gallery
 
